package com.fs.qw.service;

import com.fs.common.core.domain.R;
import com.fs.qw.domain.QwFriendWelcome;
import com.fs.qw.param.QwFriendWelcomeParam;
import com.fs.qw.vo.QwFriendWelcomeVO;

import java.util.List;

/**
 * 好友欢迎语Service接口
 *
 * @author fs
 * @date 2024-07-20
 */
public interface IQwFriendWelcomeService
{
    /**
     * 查询好友欢迎语
     *
     * @param id 好友欢迎语主键
     * @return 好友欢迎语
     */
    public QwFriendWelcomeVO selectQwFriendWelcomeById(Long id);

    /**
     * 查询好友欢迎语列表
     *
     * @param qwFriendWelcomeParam 好友欢迎语
     * @return 好友欢迎语集合
     */
    public List<QwFriendWelcome> selectQwFriendWelcomeListVO(QwFriendWelcomeParam qwFriendWelcomeParam);
    public List<QwFriendWelcome> selectQwFriendWelcomeListMyVO(QwFriendWelcomeParam qwFriendWelcomeParam);

    /**
     * 新增好友欢迎语
     *
     * @param qwFriendWelcomeParam 好友欢迎语
     * @return 结果
     */
    public R insertQwFriendWelcomeVO(QwFriendWelcomeParam qwFriendWelcomeParam);


    /**
     * 修改好友欢迎语
     *
     * @param qwFriendWelcome 好友欢迎语
     * @return 结果
     */
    public R updateQwFriendWelcome(QwFriendWelcome qwFriendWelcome);

    /**
     * 批量删除好友欢迎语
     *
     * @param ids 需要删除的好友欢迎语主键集合
     * @return 结果
     */
    public int deleteQwFriendWelcomeByIds(Long[] ids);

    /**
     * 删除好友欢迎语信息
     *
     * @param id 好友欢迎语主键
     * @return 结果
     */
    public int deleteQwFriendWelcomeById(Long id);
}
